Submit a scene to a forward pipeline.

See [PrepareSceneForwardPipelineCommonRenderData] and [PrepareSceneForwardPipelineViewDependentRenderData] if you need to render the same scene from different points of view.